==> metview_5.10.2.orig.tar.xz: metview-5.10.2/mir/src/mir/repres/unsupported/StretchedRotatedLL.h <==
/*
 * (C) Copyright 1996- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 *
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */


#ifndef StretchedRotatedLL_H
#define StretchedRotatedLL_H

#include "mir/repres/Gridded.h"


namespace mir {
namespace repres {


class StretchedRotatedLL : public Gridded {
public:
    // -- Exceptions
    // None

    // -- Constructors

    StretchedRotatedLL(const param::MIRParametrisation&);

    // -- Destructor

    virtual ~StretchedRotatedLL();  // Change to virtual if base class

    // -- Convertors
    // None

    // -- Operators
    // None

    // -- Methods

    // -- Overridden methods
    // None

    // -- Class members
    // None

    // -- Class methods
    // None

protected:
    // -- Members
    // None

    // -- Methods

    void print(std::ostream&) const;  // Change to virtual if base class

    // -- Overridden methods
    // None

    // -- Class members
    // None

    // -- Class methods
    // None

private:
    StretchedRotatedLL();

    // No copy allowed

    StretchedRotatedLL(const StretchedRotatedLL&);
    StretchedRotatedLL& operator=(const StretchedRotatedLL&);

    // -- Members


    // -- Methods
    // None


    // -- Overridden methods

    virtual void fill(grib_info&) const;

    // -- Class members
    // None

    // -- Class methods
    // None

    // -- Friends

    // friend ostream& operator<<(ostream& s,const StretchedRotatedLL& p)
    //	{ p.print(s); return s; }
};


}  // namespace repres
}  // namespace mir
#endif

==> metview_5.14.1.orig.tar.xz: metview-5.14.1/mir/src/mir/repres/unsupported/StretchedRotatedLL.h <==
/*
 * (C) Copyright 1996- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 *
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */


#pragma once

#include "mir/repres/Gridded.h"


namespace mir {
namespace repres {


class StretchedRotatedLL : public Gridded {
public:
    // -- Exceptions
    // None

    // -- Constructors

    StretchedRotatedLL(const param::MIRParametrisation&);
    StretchedRotatedLL(const StretchedRotatedLL&) = delete;

    // -- Destructor
    // None

    // -- Convertors
    // None

    // -- Operators

    StretchedRotatedLL& operator=(const StretchedRotatedLL&) = delete;

    // -- Methods
    // // None

    // -- Overridden methods
    // None

    // -- Class members
    // None

    // -- Class methods
    // None

protected:
    // -- Members
    // None

    // -- Methods

    void print(std::ostream&) const override;

    // -- Overridden methods
    // None

    // -- Class members
    // None

    // -- Class methods
    // None

private:
    // -- Members
    // None

    // -- Methods
    // None

    // -- Overridden methods
    // None

    // -- Class members
    // None

    // -- Class methods
    // None

    // -- Friends
    // None
};


}  // namespace repres
}  // namespace mir
